@@ -2,7 +2,7 @@ package Test::TCP;
 use strict;
 use warnings;
 use 5.00800;
-our $VERSION = '0.13';
+our $VERSION = '0.14';
 use base qw/Exporter/;
 use IO::Socket::INET;
 use Test::SharedFork;
@@ -10,6 +10,9 @@ use Test::More ();
 use Config;
 use POSIX;
 
+# process does not die when received SIGTERM, on win32.
+my $TERMSIG = $^O eq 'MSWin32' ? 'KILL' : 'TERM';
+
 our @EXPORT = qw/ empty_port test_tcp wait_port /;
 
 sub empty_port {
@@ -51,12 +54,19 @@ sub test_tcp {
             $err = $@;
 
             # cleanup
-            kill TERM => $pid;
-            waitpid( $pid, 0 );
-            if (WIFSIGNALED($?)) {
-                my $signame = (split(' ', $Config{sig_name}))[WTERMSIG($?)];
-                if ($signame =~ /^(ABRT|PIPE)$/) {
-                    Test::More::diag("your server received SIG$signame");
+            kill $TERMSIG => $pid;
+            while (1) {
+                my $kid = waitpid( $pid, 0 );
+                if ($^O ne 'MSWin32') { # i'm not in hell
+                    if (WIFSIGNALED($?)) {
+                        my $signame = (split(' ', $Config{sig_name}))[WTERMSIG($?)];
+                        if ($signame =~ /^(ABRT|PIPE)$/) {
+                            Test::More::diag("your server received SIG$signame");
+                        }
+                    }
+                }
+                if ($kid == 0 || $kid == -1) {
+                    last;
                 }
             }
         }
